@@ -73,7 +73,7 @@ def _init_uvicorn_logging(
     [ velodrome.error      ] logging.Logger LEVEL: 40 PROPAGATE:True
     """
 
-    name = app.title
+    name = getattr(app, "title") if hasattr(app, "title") else "starlette"
 
     # Setup uvicorn by just propagating to root logger
     uvicorn = logging.getLogger("uvicorn")
