@@ -1,10 +1,8 @@
 from typing import Sequence
 
-from opentelemetry.exporter.otlp.proto.grpc import trace_exporter
-from opentelemetry.proto.collector.trace.v1.trace_service_pb2 import (
-    ExportTraceServiceRequest,
-)
+from opentelemetry.exporter.otlp.proto.http import trace_exporter
 from opentelemetry.sdk.trace import ReadableSpan
+from opentelemetry.sdk.trace.export import SpanExportResult
 from opentelemetry.sdk.util.instrumentation import (
     InstrumentationInfo,
     InstrumentationScope,
@@ -12,10 +10,8 @@ from opentelemetry.sdk.util.instrumentation import (
 
 
 class OTLPSpanExporterDD(trace_exporter.OTLPSpanExporter):
-    def _translate_data(
-        self, data: Sequence[ReadableSpan]
-    ) -> ExportTraceServiceRequest:
-        for sdk_span in data:
+    def export(self, spans: Sequence[ReadableSpan]) -> SpanExportResult:
+        for sdk_span in spans:
             if "dd_operation_name" in sdk_span.attributes:  # type: ignore[operator]
                 # I did not find a good way to get rid of the span kind so these
                 # dd_operation_name will almost always get '.internal' appended.
@@ -28,4 +24,4 @@ class OTLPSpanExporterDD(trace_exporter.OTLPSpanExporter):
                     name=sdk_span.attributes["dd_operation_name"],  # type: ignore # noqa: E501
                     version="0.0.0",
                 )
-        return super()._translate_data(data)
+        return super().export(spans)
